/* Definition of variables*/


capture log close
*cd c:\jj\water_gurgaon\data

log using ../logfiles/definition_of_vars.out, text replace



drop if (shifted_2nd==1|shifted_3rd==1) | change_purify==2 
* replace change_purify = 0 if kind_change==3
** kind_change==3 for id 45 which stopped using municipal water and switched entirely to its tubewell. 

***** GENERATE FREQUENCY WEIGHTS TO REVERSE UNDERSAMPLING ****
gen invprobweight = 965/120 if w_quartile==0 
replace invprobweight = 965/238 if w_quartile==1
replace invprobweight = 965/251 if w_quartile==2
replace invprobweight = 965/244 if w_quartile==3
replace invprobweight = 965/112 if w_quartile==4


/*Creating pre-purified water and post-purified water*/

* gen unpurified = raw_water



gen raw_dirty = raw_water

replace raw_dirty = drink_water if flagpurify==0
label variable raw_dirty "Dummy for dirty (+ve) on unpurified water"


gen purified_dirty = drink_water==1 & flagpurify==1

label variable purified_dirty "Dummy for dirty (+ve) on purified water, and zero for all hh's that did not purify"

gen drink_clean = 1 - drink_water
label variable drink_clean "Dummy for drinking water tested clean"

/*Interacting treatment with unpurified contaminated and uncontaminated water*/

gen t_rw1 = treatment*raw_dirty

gen t_rw0 = treatment*(1-raw_dirty)



/*Interaction of treatment and drinking water results*/

gen t_dw0 = treatment*drink_clean

gen t_dw1 = treatment*drink_water

label variable t_dw0 "Treatment group interacted with uncontaminated drinking water"

label variable t_dw1 "Treatment group interacted with contaminated drinking water"



/*Interaction of awareness index, drink water results and treatment group*/ 

gen t_dw0_aware = t_dw0*awareness 

gen t_dw1_aware = t_dw1*awareness 

gen treatment_aware = treatment*awareness 

label variable t_dw0_aware "Treatment group interacted with awareness index & drinkwater contaminated"

label variable t_dw1_aware "Treatment group interacted with awareness index & drinkwater contaminated"

label variable treatment_aware "Treatment group interacted with awareness index"



/*Interaction of wealth index, drink water results and treatment group*/ 

gen t_dw0_wealth = t_dw0*wealth 

gen t_dw1_wealth = t_dw1*wealth 

gen treatment_wealth = treatment*wealth 

label variable t_dw0_wealth "Treatment group interacted with wealth index & drinkwater contaminated"

label variable t_dw1_wealth "Treatment group interacted with wealth index & drinkwater not contaminated"

label variable treatment_wealth "Treatment group interacted with wealth index"


/*Interaction of maximum years of education among adult females, drink water results and treatment group*/ 

gen t_dw0_maxfedu = t_dw0*maxfedu 

gen t_dw1_maxfedu = t_dw1*maxfedu 

gen t_rw0_maxfedu = t_rw0*maxfedu 

gen t_rw1_maxfedu = t_rw1*maxfedu 

gen treatment_maxfedu = treatment*maxfedu 

label variable t_dw0_maxfedu "Treatment group interacted with maximum years of education among female adults & drinkwater contaminated"

label variable t_dw1_maxfedu "Treatment group interacted with maximum years of education among female & drinkwater not contaminated"

label variable treatment_maxfedu "Treatment group interacted with maximum years of education among female"

gen maxedu = max(maxmedu, maxfedu)
gen t_dw1_maxedu = t_dw1*maxedu


/*Categorizing households with more than median wealth and those with less than median wealth. 

Interacting this with treatment*/

egen medwealth = median(wealth)

gen byte wu = wealth>medwealth

gen byte wl = 1 - wu

gen tt_wu = treatment*wu

gen tt_wl = treatment*wl



/*Categorizing households with more than median awareness and those with less than median awareness. 

Interacting this with treatment*/

egen medaware = median(awareness)

gen byte au = awareness>medaware

gen byte al = 1 - au

gen tt_au = treatment*au

gen tt_al = treatment*al


/*Categorizing households with more than median female education and those with less than median female education. 

Interacting this with treatment*/

egen medmaxfedu = median(maxfedu)

gen byte feu = maxfedu>medmaxfedu
gen byte fel = 1 - feu

gen tt_feu = treatment*feu

gen tt_fel = treatment*fel



/*Interacting awareness categories with drinking water results and treatment groups*/

gen t_dw1_au = t_dw1*au

gen t_dw0_au = t_dw0*au

gen t_dw1_al = t_dw1*al

gen t_dw0_al = t_dw0*al



/*Interacting wealth categories with drinking water results and treatment groups*/

gen t_dw1_wu = t_dw1*wu

gen t_dw0_wu = t_dw0*wu

gen t_dw1_wl = t_dw1*wl

gen t_dw0_wl = t_dw0*wl



/*Interacting wealth categories with raw water results and treatment groups*/

gen t_rw1_wu = t_rw1*wu

gen t_rw0_wu = t_rw0*wu

gen t_rw1_wl = t_rw1*wl

gen t_rw0_wl = t_rw0*wl



/*Interacting awareness categories with raw water results and treatment groups*/

gen t_rw1_au = t_rw1*au

gen t_rw0_au = t_rw0*au

gen t_rw1_al = t_rw1*al

gen t_rw0_al = t_rw0*al



/*Interacting wealth and awareness with contaminated drink water*/

gen t_rw0_au_wu=t_rw0*au*wu

gen t_dw1_au_wu=t_dw1*au*wu

gen t_dw1_au_wl = t_dw1*au*wl
gen t_dw1_al_wu = t_dw1*al*wu
gen t_dw1_al_wl = t_dw1*al*wl


gen t_dw1_wu_maxfedu=t_dw1*wu*maxfedu


/*Interacting clean raw water result with dirty drinking water result.  
This is to be included for initial purifiers subsample*/
gen interaction=t_rw0*t_dw1

log close

