version 8.1
capture log close 
drop _all 
set more off

*cd C:\jj\water_gurgaon\data

log using ..\logfiles\final_fillin_rev2.out, text replace 

use hh_data_f, clear 

mvdecode _all, mv(999)
replace id = 999 if id==.

*** Page 1 *****
label variable collected_raw "Dummy for raw water collected (see also nfd)"
label variable nfd "Is not missing means raw water was not for drinking, hence irrelevant"
label variable collected_drinking "Dummy for drinking water (raw or purified) collected"
label variable raw_water "Dummy for raw water being dirty (testing positive)"
label variable drink_water "Dummy for drinking water being dirty (testing positive)"

replace raw_water = . if id==51  /* collected_raw == . for id==51 but raw_water==0 */


*** Awareness Module (page 5) *****
renpfix specify_ specify 

foreach var of varlist *_1 *_2 *_3 *_4 *_5 { 
replace `var' = 0 if `var'==. 
}

/*
foreach var of varlist *_2 { 
replace `var' = 0 if `var'==. & infection_1==1
}
*/

*****Diarrhea & Filtration Module (page 6) *****

****************************************

********* Water Supply (page 7) *************

foreach var of varlist conspt* { 
replace `var' = 0 if `var'==. 
}

foreach var of varlist pay_* { 
replace `var' = 0 if `var'==. 
}

replace paymnt_pipe = 0 if paymnt_pipe==. & pay_pipe==0
replace paymnt_twell = 0 if paymnt_twell==. & pay_tube==0
replace paymnt_pump = 0 if paymnt_pump==. & pay_pump==0
replace paymnt_tank = 0 if paymnt_tank==. & pay_tank==0
replace paymnt_bottle = 0 if paymnt_bottle==. & pay_bottle==0
replace paymnt_others = 0 if paymnt_others==. & pay_others==0
*********** Water Supply (page 8) *************

#delimit ;
foreach var of varlist straina_* strainb_* strainc_* tableta_* tabletb_* tabletc_* 
nnelecta_* nnelectb_* nnelectc_* electa_* electb_* electc_* boila_* boilb_* boilc_*
{ ;
replace `var' = 0 if `var'==. ;
} ;

*********** page 9 ***************** ;

gen byte flagpurify = nfd==. & collected_raw==1 & collected_drinking==1 ;
label variable flagpurify "Purification dummy";
tab flagpurify ;

gen byte flagstrain=0 ;
replace flagstrain=1 if 
(straina_pipe!=0 | straina_tube!=0 | straina_pump!=0 | straina_tank!=0 | 
straina_bottle!=0 | straina_other!=0) & flagpurify==1;
label variable flagstrain "Straining used";

gen byte flagtab=0;
label variable flagtab "Tablet Used";
replace flagtab=1  if (tableta_pipe!=0 | tableta_tube!=0 | tableta_pump!=0 | 
tableta_tank!=0 | tableta_bottle!=0 | tableta_other!=0)& flagpurify==1;

gen byte flagnnelect=0;
label variable flagnnelect "NonElectric Filter Used";
replace flagnnelect=1  if (nnelecta_pipe!=0 | nnelecta_tube!=0 | nnelecta_pump!=0 |
 nnelecta_tank!=0 | nnelecta_bottle!=0 | nnelecta_other!=0)& flagpurify==1;

gen byte flagelect=0;
label variable flagelect "Electric Filter Used";
replace flagelect=1  if (electa_pipe!=0 | electa_tube!=0 | electa_pump!=0 |
 electa_tank!=0 | electa_bottle!=0 | electa_other!=0) & flagpurify==1;

gen byte flagboil=0;
label variable flagboil "Boiling method Used";
replace flagboil=1  if (boila_pipe!=0 | boila_tube!=0 | boila_pump!=0 |
 boila_tank!=0 | boila_bottle!=0 | boila_other!=0) & flagpurify==1;

gen byte flagbottle = consptbottlea > 0 & flagpurify==1;
label variable flagbottle "Bottled water Used";

replace flagelect=1 if id==262 ; /* RO */
replace flagnnelect=0 if id==262 ;

gen byte purify_type = 0 if flagpurify==0;
replace purify_type = 1 if flagstrain==1;
replace purify_type = 2 if flagtab==1;
replace purify_type = 3 if flagnnelect==1;
replace purify_type = 4 if flagelect==1;
replace purify_type = 5 if flagboil==1;
replace purify_type = 6 if flagbottle==1 ;

label define purify_lbl 
0 "No Purification" 
1 "Straining" 
2 "Tablets/drops" 
3 "Non-electric"
4 "Electric"
5 "Boiling" 
6 "Bottled water"
7 "RO";

label values purify_type purify_lbl ;
label variable purify_type "1st round purification method" ;

gen new_purify_type = purify_type if change_purify==0 ;
replace new_purify_type = 0 if kind_change==2 ;
replace new_purify_type = 1 if new_method==5 ;
replace new_purify_type = 2 if new_method==4 ;
replace new_purify_type = 3 if new_method==2 ;
replace new_purify_type = 4 if new_method==1  ;
replace new_purify_type = 5 if new_method==3 ;
replace new_purify_type = 6 if new_method==6 ;
replace new_purify_type = 7 if new_method==7 ;
label values new_purify_type purify_lbl ;
label variable new_purify_type "3rd round purification method created from new_method in final_fillin.do" ;

gen byte saystrain = straina_pipe!=0 | straina_tube!=0 | straina_pump!=0 | straina_tank!=0 | 
straina_bottle!=0 | straina_other!=0 ;
label variable saystrain "Straining said to be used";

gen byte saytab = tableta_pipe!=0 | tableta_tube!=0 | tableta_pump!=0 | 
tableta_tank!=0 | tableta_bottle!=0 | tableta_other!=0;
label variable saytab "Tablet said to be used";

gen byte saynnelect = nnelecta_pipe!=0 | nnelecta_tube!=0 | nnelecta_pump!=0 |
 nnelecta_tank!=0 | nnelecta_bottle!=0 | nnelecta_other!=0;
label variable saynnelect "NonElectric Filter said to be used";

gen byte sayelect = electa_pipe!=0 | electa_tube!=0 | electa_pump!=0 |
 electa_tank!=0 | electa_bottle!=0 | electa_other!=0;
label variable sayelect "Electric Filter said to be used";

gen byte sayboil=boila_pipe!=0 | boila_tube!=0 | boila_pump!=0 |
 boila_tank!=0 | boila_bottle!=0 | boila_other!=0;
label variable sayboil "Boiling method said to be used";

gen byte saybottle = consptbottlea > 0 ;
label variable saybottle "bottled water said to be used";

gen byte saypurify = saystrain==1 | saytab==1 |saynnelect==1 |sayelect==1 |sayboil==1 |
saybottle==1 ; 
label variable saypurify "Water said to be purified (1st round)" ;

gen byte purify_say = 0 if saypurify==0;
replace purify_say = 1 if saystrain==1;
replace purify_say = 2 if saytab==1;
replace purify_say = 3 if saynnelect==1;
replace purify_say = 4 if sayelect==1;
replace purify_say = 5 if sayboil==1;
replace purify_say = 6 if saybottle==1 ;

label values purify_say purify_lbl ;

**** Corrections **** ;

label variable change_purify "Dummy for change in purification behaviour (0=unchanged)" ;
label define change_lbl 0 "No change" 1 "Changed" ;
label values change_purify change_lbl ;

label variable kind_change "Kind of change in purification behaviour" ;
label define kind_change_lbl 0 "No change" 1 "Adopted new method" 2 "Stopped purifying" 3 "Changed water source" ;
label values kind_change kind_change_lbl ;

replace change_purify = 0 if purify_type==0 & kind_change==2 ;
replace kind_change = 0 if change_purify==0 & kind_change==2 ;

*** Household was not using filtration in the first round in winter (season A) or
it said it was but failed to provide a sample of purified water. ;



foreach var of varlist fixed_nnelec vari_nnelec
{ ;
replace `var' = 0 if `var'==. & flagnnelect == 0;
} ;

foreach var of varlist fixed_elec vari_elec
{ ;
replace `var' = 0 if `var'==. & flagelect == 0;
} ;

foreach var of varlist 
earthen plastic othernonmetal iron copper steel brass othermetal nostorage 
{ ;
replace `var' = 0 if `var'==. ;
} ;

foreach var of varlist water_taken* { ;
replace `var' = 0 if `var'==. ;
} ;

**********************************;



******* Create Awareness and Wealth Index ******;

gen infectedwater = infection_1*water_2 ;
for var infectedwater  water_1  purify_water_3 pro_clean_water_4  sanitation_4  water_taken4 
\ new a_var1-a_var6: egen Y = std(X);

/*Using factor command to extract first principal component*/

factor a_var1-a_var6, pc factors(1);

/*Creating the awareness index using the elements of the first eigen vector of 
the principal component analysis*/

score awareness;
****;

foreach var of varlist refriegerator radio computer television phone washing_machine bicycle 
_2_wheeler _4_wheeler house_poss land_poss rooms nature_of_house separate_kitchen 
outlet_in_kitchen { ;
replace `var' = 0 if `var'==. ;
} ;

replace house_poss=1 if house_poss==0 & type_of_house==1;
gen flagroom = rooms==3 | rooms==4;;

for var refriegerator radio computer television phone washing_machine bicycle 
_2_wheeler _4_wheeler house_poss land_poss flagroom nature_of_house separate_kitchen 
outlet_in_kitchen
 \ new b_var1-b_var15: egen Y = std(X);

/*Using factor command to extract first principal component*/

factor b_var1-b_var15, pc factors(1);

/*Creating the wealth index using the elements of the first eigen vector of the principal component analysis*/

score wealth;

drop a_* b_* ;

sort id;
save hh_data_f, replace;

use page16_17, clear ;

foreach var of varlist age gen_edu exposure_school treat_place treatment { ;
               replace `var' = . if `var'==99 | `var'==999;
        };

/*Creating education variables from the personal file*/
egen a1 = max(gen_edu) if age>=18 & sex==2, by (id);
egen a2 = max(gen_edu) if age>=18 & sex==1, by (id);

foreach var of varlist a1 a2 { ;
replace `var' = 0 if `var'==. ;
};

egen a11 = max(a1), by(id);
egen a12 = max(a2), by(id);

drop a1 a2;

rename a11 maxfedu;
rename a12 maxmedu;
  
replace maxmedu=. if maxmedu==999;
replace maxfedu=. if maxfedu==999;

/*Gender, Age of head of household*/
gen head_sex=(sex==1 & reln_hh==1);
gen head_age=age if (reln_hh==1);
foreach var of varlist head_sex head_age { ;
replace `var' = 0 if `var'==. ;
};

egen sex_head = max(head_sex), by(id);
egen age_head = max(head_age), by(id);

drop head_sex head_age;

/* Occupation of the head of the household*/
gen head_occupation=usual_activity if (reln_hh==1);
foreach var of varlist head_occupation { ;
replace `var' = 0 if `var'==. ;
};

egen occupation_head = max(head_occupation), by(id);
drop head_occupation ;

/*Number of children between 0 -3 years*/;
gen flag0t3=age<=3;replace flag0t3=0 if flag0t3==.;
egen child0t3=sum(flag0t3), by(id);

drop flag0t3;

/* Number of diarrhea cases */
egen byte diarrhea_cases = sum(diarrhea), by(id) ;
drop diarrhea ;
gen byte diarrhea = diarrhea_cases > 0 ;
label variable diarrhea_cases "Number of cases of diarrhea in household in past month" ;
label variable diarrhea "dummy for occurrence of diarrhea in household in past month" ;

/*no of members in each household*/
egen no_members = max(mem_id) , by (id);

sort id;
qui by id: drop if _n>1;

sort id;
merge id using hh_data_f, _merge(m_hh_personal);
tab m_hh_personal;

rename treatment treatment_survey;
gen treatment = category_household=="T" ;
label variable treatment "dummy for treatment group" ;

/* GENERATE PURIFICATION EXPENDITURE */
#delimit;
scalar rate=.1;
scalar flow = (rate)/(1-(1/(1+rate)^10));

/* First round expenditure */
gen old_cost=0;

/*Tablets*/
replace old_cost=365 if purify_type==2; /*Inserted by JJ on Nov29, 2006*/
/*tablets (1 bottle of 60 tabs is Rs 60. 1 tab per day purifies 10 liters or 2 lit per person*/ ;

/*Non-electric filter*/
replace vari_nnelec = 0 if vari_nnelec==. & fixed_nnelec!=. ;
replace old_cost = fixed_nnelec*flow + vari_nnelec if purify_type==3 & (fixed_nnelec~=. & fixed_nnelec~=0);

egen ne_fixed_mean= mean(fixed_nnelec) if purify_type==3;
egen min_ne_fixed_mean = min(ne_fixed_mean) ;
egen ne_vari_mean= mean(vari_nnelec) if purify_type==3;
egen min_ne_vari_mean = min(ne_vari_mean) ;

replace old_cost = flow*min_ne_fixed_mean + min_ne_vari_mean if purify_type==3 &(fixed_nnelec==.|fixed_nnelec==0);
	
/*Electric filter*/
replace vari_elec = 0 if vari_elec==. & fixed_elec!=. ;
replace old_cost = fixed_elec*flow + vari_elec if purify_type==4 & (fixed_elec~=. & fixed_elec~=0);

egen e_fixed_mean= mean(fixed_elec) if purify_type==4;
egen min_e_fixed_mean = min(e_fixed_mean) ;
egen e_vari_mean= mean(vari_elec) if purify_type==4;
egen min_e_vari_mean = min(e_vari_mean) ;

replace old_cost = flow*min_e_fixed_mean + min_e_vari_mean if (fixed_elec==.|fixed_elec==0) & purify_type==4;

/*Boiling*/
replace old_cost = 365*(177/60)*timeboil*(250/14200) if purify_type==5 & timeboil!=. ;

/* Bottled Water*/
replace old_cost = paymnt_bottle*52 if flagbottle==1 & paymnt_bottle<180; /* Numbers too low if not weekly */
replace old_cost = paymnt_bottle*12 if flagbottle==1 & paymnt_bottle==180;

/* RO */
/* Was classified as electric filter in first round */

/* THIRD-ROUND EXPENDITURE */
gen nexp = old_cost ;
replace nexp = 0 if kind_change==2 ;

replace nexp = 0 if change_purify==1 & new_purify_type==1 ; /* Straining */
replace nexp = 365 if change_purify==1 & new_purify_type==2 
/*tablets (1 bottle of 60 tabs is Rs 60. 1 tab per day purifies 10 liters or 2 lit per person*/ ;

replace nexp = cost_3rd*52 if change_purify==1 & new_purify_type==6 /*bottles (reported cost assumed to be for a week)*/ ;
replace nexp = cost_3rd*flow if new_purify_type==7 /* RO () */;

egen aquacost_mean=mean(cost_3rd) if new_method==1 & cost_3rd~=.& cost_3rd~=0 & brand_3rd=="Aquaguard";
egen minaquacost_mean = min(aquacost_mean) ;
replace cost_3rd=minaquacost_mean if (cost_3rd==.| cost_3rd==0) & (new_method==1); 
replace nexp = cost_3rd*flow if new_method==1 /*Electronic filter*/;

egen zeroBcost_mean=mean(cost_3rd) if new_method==2 & cost_3rd~=.& cost_3rd~=0 & brand_3rd=="Zero B";
egen minzeroBcost_mean = min(zeroBcost_mean) ;
replace cost_3rd=minzeroBcost_mean if (cost_3rd==.| cost_3rd==0) & (new_method==2)& brand_3rd=="Zero B"; 

egen localcost_mean=mean(cost_3rd) if new_method==2 & cost_3rd~=.& cost_3rd~=0 & brand_3rd=="Local";
egen minlocalcost_mean = min(localcost_mean) ;
replace cost_3rd=minlocalcost_mean if (cost_3rd==.| cost_3rd==0) & (new_method==2)& brand_3rd==""; 

egen prestigecost_mean=mean(fixed_nnelec) if name_nnelect_filter=="Prestige";
egen minprestigecost_mean = min(prestigecost_mean) ;
replace cost_3rd=minprestigecost_mean if (cost_3rd==.| cost_3rd==0) & (new_method==2)& brand_3rd=="Prestige"; 

egen PNBcost_mean=mean(fixed_nnelec) if name_nnelect_filter=="PNB";

egen minPNBcost_mean = min(PNBcost_mean) ;
replace cost_3rd=minPNBcost_mean if (cost_3rd==.| cost_3rd==0) & (new_method==2)& brand_3rd=="PNB"; 
replace nexp = cost_3rd*flow if new_method==2 /*Non-electric filter*/;

replace nexp = 365*(177/60)*time_boil_3rd*(250/14200) if new_method==3;
/* Big burner gas consumption is 177 gm/hr (sunflame.com). 
Cylinder is 14200gm. Cylinder price is 250 */

/*Calculating the expenditure on candle change of existing electric and non-electric filters*/
gen candlechange=0;

egen candlechange_ne = mean(cost_candle_change) if (cost_candle_change~=.| cost_candle_change~=0) 
  & change_candle==1 & purify_type==3;	
egen min_candlechange_ne = min(candlechange_ne);
replace candlechange=min_candlechange_ne if change_candle==1 & purify_type==3 & 
	(cost_candle_change==.|cost_candle_change==0);
replace candlechange=cost_candle_change if change_candle==1 & purify_type==3 & 
	(cost_candle_change~=. & cost_candle_change~=0);

egen candlechange_e = mean(cost_candle_change) if (cost_candle_change~=.| cost_candle_change~=0) 
  & change_candle==1 & purify_type==4;	
egen min_candlechange_e = min(candlechange_e);
replace candlechange=min_candlechange_e if change_candle==1 & purify_type==4 &
	(cost_candle_change==.|cost_candle_change==0);
replace candlechange=cost_candle_change if change_candle==1 & purify_type==4 &
	(cost_candle_change~=. & cost_candle_change~=0);

gen avertingbehavior = change_purify;
replace avertingbehavior = 1 if (expenditure_repair==1|change_candle==1| same_storage==0|same_method_water_takenout==0);
replace avertingbehavior = 1 if amc_3rd>0 & amc_3rd~=.; /*AMC taken*/
label variable avertingbehavior "Dummy for changed purification behavior, including repairs, candle changes etc." ;

/*Total new expenditure made by households*/
gen dexp = 0 ;
replace dexp = nexp - old_cost if change_purify==1 & kind_change!=3;
label variable dexp "Increase in expenditure between 1st & 3rd rounds, not including maintenance expenditures" ;
su dexp, detail;

/*Changing the definition of expenses incurred due to experiment to include expenditures on candle change, AMC and repairs*/
gen expenditure = 0 ;
replace expenditure = nexp - old_cost + candlechange + amc_3rd  if avertingbehavior==1 & kind_change!=3 ;
label variable expenditure "Increase in expenditure, including maintenance expenditure, between 1st & 3rd rounds" ;
/*No costs available for repairs so that is not included in the definition*/
/*In the earlier version because of incorrect definition of averting behavior type dummy cost of candlechange was not */
/*included in expenditure changes. There are 116 households that made some expenditures on candle change which doubles*/
/*the mean expenditure from previous expenditures */



gen changed_method = kind_change==1 ;
label variable changed_method "Dummy for changed purification method" ;

***** GENERATE FREQUENCY WEIGHTS TO REVERSE UNDERSAMPLING IN ORIGINAL SAMPLE**** ;
gen invprobweight = 1006/130 if w_quartile==0 ;
replace invprobweight = 1006/256 if w_quartile==1 ;
replace invprobweight = 1006/254 if w_quartile==2 ;
replace invprobweight = 1006/250 if w_quartile==3 ;
replace invprobweight = 1006/116 if w_quartile==4 ;
save hhind_data_1006, replace ;
drop invprobweight ;
log close ;
do "..\programs\definitions of variables.do" /*Creates the variables necessary to run the regressions*/ ;

log using ..\logfiles\final_fillin_rev2.out, text append ;


save hhind_data_f_rev, replace ;

log close
